package com.bonus.sgzb.base.mapper;

import com.bonus.sgzb.base.domain.MaSupplierInfo;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * 供应商管理ma_supplier_infoMapper接口
 * 
 * @author bonus
 * @date 2023-12-10
 */
@Mapper
public interface MaSupplierInfoMapper 
{
    /**
     * 查询供应商管理ma_supplier_info
     * 
     * @param supplierId 供应商管理ma_supplier_info主键
     * @return 供应商管理ma_supplier_info
     */
    public MaSupplierInfo selectMaSupplierInfoBySupplierId(Long supplierId);

    /**
     * 查询供应商管理ma_supplier_info列表
     * 
     * @param maSupplierInfo 供应商管理ma_supplier_info
     * @return 供应商管理ma_supplier_info集合
     */
    public List<MaSupplierInfo> selectMaSupplierInfoList(MaSupplierInfo maSupplierInfo);

    /**
     * 新增供应商管理ma_supplier_info
     * 
     * @param maSupplierInfo 供应商管理ma_supplier_info
     * @return 结果
     */
    public int insertMaSupplierInfo(MaSupplierInfo maSupplierInfo);

    /**
     * 修改供应商管理ma_supplier_info
     * 
     * @param maSupplierInfo 供应商管理ma_supplier_info
     * @return 结果
     */
    public int updateMaSupplierInfo(MaSupplierInfo maSupplierInfo);

    /**
     * 删除供应商管理ma_supplier_info
     * 
     * @param supplierId 供应商管理ma_supplier_info主键
     * @return 结果
     */
    public int deleteMaSupplierInfoBySupplierId(Long supplierId);

    /**
     * 批量删除供应商管理ma_supplier_info
     * 
     * @param supplierIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteMaSupplierInfoBySupplierIds(Long[] supplierIds);
}
